@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeblock.h"
+#include <ccode/valaccodeblock.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/collection.h>
-#include <ccode/valaccodeblock.h>
 
 struct _ValaCCodeBlockPrivate {
 	gboolean _suppress_newline;
@@ -43,8 +42,7 @@ static void vala_ccode_block_dispose (GObject * obj);
 /**
  * Prepend the specified statement to the list of statements.
  */
-void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* statement)
-{
+void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
 	gee_list_insert (self->priv->statements, 0, statement);
@@ -54,8 +52,7 @@ void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* st
 /**
  * Append the specified statement to the list of statements.
  */
-void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statement)
-{
+void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statement) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
 	/* allow generic nodes to include comments */
@@ -63,10 +60,9 @@ void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statem
 }
 
 
-static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeBlock * self;
-	self = ((ValaCCodeBlock*) base);
+	self = VALA_CCODE_BLOCK (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_begin_block (writer);
 	{
@@ -106,78 +102,82 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 }
 
 
-gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self)
-{
+/**
+ * Represents a C code block.
+ */
+ValaCCodeBlock* vala_ccode_block_new (void) {
+	ValaCCodeBlock * self;
+	self = g_object_newv (VALA_TYPE_CCODE_BLOCK, 0, NULL);
+	return self;
+}
+
+
+gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_BLOCK (self), FALSE);
 	return self->priv->_suppress_newline;
 }
 
 
-void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value)
-{
+void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	self->priv->_suppress_newline = value;
 }
 
 
-static void vala_ccode_block_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_block_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCCodeBlock * self;
 	self = VALA_CCODE_BLOCK (object);
 	switch (property_id) {
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		g_value_set_boolean (value, vala_ccode_block_get_suppress_newline (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_block_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_ccode_block_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCCodeBlock * self;
 	self = VALA_CCODE_BLOCK (object);
 	switch (property_id) {
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		vala_ccode_block_set_suppress_newline (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass)
-{
+static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass) {
 	vala_ccode_block_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeBlockPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_block_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_block_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_block_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_block_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BLOCK_SUPPRESS_NEWLINE, g_param_spec_boolean ("suppress-newline", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_BLOCK_SUPPRESS_NEWLINE, g_param_spec_boolean ("suppress-newline", "suppress-newline", "suppress-newline", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_ccode_block_init (ValaCCodeBlock * self)
-{
+static void vala_ccode_block_init (ValaCCodeBlock * self) {
 	self->priv = VALA_CCODE_BLOCK_GET_PRIVATE (self);
 	self->priv->statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_block_dispose (GObject * obj)
-{
+static void vala_ccode_block_dispose (GObject * obj) {
 	ValaCCodeBlock * self;
-	ValaCCodeBlockClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_BLOCK (obj);
 	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_object_unref (self->priv->statements), NULL)));
-	klass = VALA_CCODE_BLOCK_CLASS (g_type_class_peek (VALA_TYPE_CCODE_BLOCK));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_block_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_block_get_type (void)
-{
+GType vala_ccode_block_get_type (void) {
 	static GType vala_ccode_block_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_block_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBlock), 0, (GInstanceInitFunc) vala_ccode_block_init };
