@@ -1,11 +1,11 @@
 /* valaccodecasestatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODECASESTATEMENT_H__
-#define __VALACCODECASESTATEMENT_H__
+#ifndef __CCODE_VALACCODECASESTATEMENT_H__
+#define __CCODE_VALACCODECASESTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -54,11 +54,11 @@ struct _ValaCCodeCaseStatementClass {
 	ValaCCodeStatementClass parent;
 };
 
-ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expr);
+ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression);
 void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, ValaCCodeStatement* stmt);
 ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStatement* self);
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value);
-GType vala_ccode_case_statement_get_type ();
+GType vala_ccode_case_statement_get_type (void);
 
 G_END_DECLS
 
