@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodefragment.h"
+#include <ccode/valaccodefragment.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
-#include <ccode/valaccodefragment.h>
 
 struct _ValaCCodeFragmentPrivate {
 	GeeList* children;
@@ -45,8 +44,7 @@ static void vala_ccode_fragment_dispose (GObject * obj);
  *
  * @param node a C code node
  */
-void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node)
-{
+void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
 	g_return_if_fail (VALA_IS_CCODE_FRAGMENT (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->children), node);
@@ -58,17 +56,15 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node)
  *
  * @return children list
  */
-GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self)
-{
+GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FRAGMENT (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->children)));
 }
 
 
-static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
-	self = ((ValaCCodeFragment*) base);
+	self = VALA_CCODE_FRAGMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
@@ -88,10 +84,9 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 }
 
 
-static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
-	self = ((ValaCCodeFragment*) base);
+	self = VALA_CCODE_FRAGMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
@@ -111,10 +106,9 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 }
 
 
-static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
-	self = ((ValaCCodeFragment*) base);
+	self = VALA_CCODE_FRAGMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
@@ -134,8 +128,17 @@ static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCC
 }
 
 
-static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass)
-{
+/**
+ * Represents a container for C code nodes.
+ */
+ValaCCodeFragment* vala_ccode_fragment_new (void) {
+	ValaCCodeFragment * self;
+	self = g_object_newv (VALA_TYPE_CCODE_FRAGMENT, 0, NULL);
+	return self;
+}
+
+
+static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass) {
 	vala_ccode_fragment_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeFragmentPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_fragment_dispose;
@@ -145,28 +148,21 @@ static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass)
 }
 
 
-static void vala_ccode_fragment_init (ValaCCodeFragment * self)
-{
+static void vala_ccode_fragment_init (ValaCCodeFragment * self) {
 	self->priv = VALA_CCODE_FRAGMENT_GET_PRIVATE (self);
 	self->priv->children = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_fragment_dispose (GObject * obj)
-{
+static void vala_ccode_fragment_dispose (GObject * obj) {
 	ValaCCodeFragment * self;
-	ValaCCodeFragmentClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_FRAGMENT (obj);
 	(self->priv->children == NULL ? NULL : (self->priv->children = (g_object_unref (self->priv->children), NULL)));
-	klass = VALA_CCODE_FRAGMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FRAGMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_fragment_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_fragment_get_type (void)
-{
+GType vala_ccode_fragment_get_type (void) {
 	static GType vala_ccode_fragment_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_fragment_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_init };
