@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,15 +20,14 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODELINEDIRECTIVE_H__
-#define __VALACCODELINEDIRECTIVE_H__
+#ifndef __CCODE_VALACCODELINEDIRECTIVE_H__
+#define __CCODE_VALACCODELINEDIRECTIVE_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
-#include <ccode/valaccodewriter.h>
 
 G_BEGIN_DECLS
 
