@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodestatement.h"
+#include <ccode/valaccodestatement.h>
 
 enum  {
 	VALA_CCODE_STATEMENT_DUMMY_PROPERTY
@@ -28,19 +28,16 @@ enum  {
 static gpointer vala_ccode_statement_parent_class = NULL;
 
 
-static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass)
-{
+static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass) {
 	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_ccode_statement_init (ValaCCodeStatement * self)
-{
+static void vala_ccode_statement_init (ValaCCodeStatement * self) {
 }
 
 
-GType vala_ccode_statement_get_type (void)
-{
+GType vala_ccode_statement_get_type (void) {
 	static GType vala_ccode_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_init };
