@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,12 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "set.h"
+#include <gee/set.h>
 
 
 
-static void gee_set_base_init (GeeSetIface * iface)
-{
+static void gee_set_base_init (GeeSetIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
 		initialized = TRUE;
@@ -33,8 +32,7 @@ static void gee_set_base_init (GeeSetIface * iface)
 }
 
 
-GType gee_set_get_type (void)
-{
+GType gee_set_get_type (void) {
 	static GType gee_set_type_id = 0;
 	if (G_UNLIKELY (gee_set_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (GeeSetIface), (GBaseInitFunc) gee_set_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
