@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaclassregisterfunction.h"
+#include <gobject/valaclassregisterfunction.h>
 #include <vala/valatypereference.h>
 #include <vala/valainterface.h>
 #include <ccode/valaccodedeclaration.h>
@@ -33,7 +33,6 @@
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeidentifier.h>
 #include <ccode/valaccodeexpressionstatement.h>
-#include <gobject/valaclassregisterfunction.h>
 
 struct _ValaClassRegisterFunctionPrivate {
 	ValaClass* _class_reference;
@@ -64,8 +63,7 @@ static void vala_class_register_function_dispose (GObject * obj);
  * @param cl a class
  * @return   newly created class register function
  */
-ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl)
-{
+ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl) {
 	ValaClassRegisterFunction * self;
 	g_return_val_if_fail (VALA_IS_CLASS (cl), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS_REGISTER_FUNCTION, 0, NULL);
@@ -74,82 +72,74 @@ ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl)
 }
 
 
-static ValaDataType* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base)
-{
+static ValaDataType* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	return VALA_DATA_TYPE (g_object_ref (vala_class_register_function_get_class_reference (self)));
 }
 
 
-static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	return g_strdup ("NULL");
 }
 
 
-static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_strdup_printf ("%s_class_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static char* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_data_type_get_cname (VALA_DATA_TYPE (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static char* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	return vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (vala_class_get_base_class (vala_class_register_function_get_class_reference (self))), "TYPE_");
 }
 
 
-static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base)
-{
+static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	self = ((ValaClassRegisterFunction*) base);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	if (vala_class_get_is_abstract (vala_class_register_function_get_class_reference (self))) {
 		return g_strdup ("G_TYPE_FLAG_ABSTRACT");
 	} else {
@@ -158,20 +148,18 @@ static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterF
 }
 
 
-static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base)
-{
+static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	self = ((ValaClassRegisterFunction*) base);
-	return vala_symbol_get_access (((ValaSymbol*) vala_class_register_function_get_class_reference (self)));
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	return vala_symbol_get_access (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)));
 }
 
 
-static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base)
-{
+static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	ValaCCodeFragment* frag;
-	self = ((ValaClassRegisterFunction*) base);
-	frag = g_object_new (VALA_TYPE_CCODE_FRAGMENT, NULL);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	frag = vala_ccode_fragment_new ();
 	{
 		GeeCollection* base_type_collection;
 		GeeIterator* base_type_it;
@@ -229,12 +217,11 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 }
 
 
-static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base)
-{
+static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	ValaCCodeFragment* frag;
-	self = ((ValaClassRegisterFunction*) base);
-	frag = g_object_new (VALA_TYPE_CCODE_FRAGMENT, NULL);
+	self = VALA_CLASS_REGISTER_FUNCTION (base);
+	frag = vala_ccode_fragment_new ();
 	{
 		GeeCollection* base_type_collection;
 		GeeIterator* base_type_it;
@@ -306,22 +293,19 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 }
 
 
-ValaClass* vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self)
-{
+ValaClass* vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self) {
 	g_return_val_if_fail (VALA_IS_CLASS_REGISTER_FUNCTION (self), NULL);
 	return self->priv->_class_reference;
 }
 
 
-void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value)
-{
+void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value) {
 	g_return_if_fail (VALA_IS_CLASS_REGISTER_FUNCTION (self));
 	self->priv->_class_reference = value;
 }
 
 
-static void vala_class_register_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_class_register_function_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (object);
 	switch (property_id) {
@@ -335,8 +319,7 @@ static void vala_class_register_function_get_property (GObject * object, guint p
 }
 
 
-static void vala_class_register_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_class_register_function_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (object);
 	switch (property_id) {
@@ -350,8 +333,7 @@ static void vala_class_register_function_set_property (GObject * object, guint p
 }
 
 
-static void vala_class_register_function_class_init (ValaClassRegisterFunctionClass * klass)
-{
+static void vala_class_register_function_class_init (ValaClassRegisterFunctionClass * klass) {
 	vala_class_register_function_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaClassRegisterFunctionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_class_register_function_get_property;
@@ -368,30 +350,23 @@ static void vala_class_register_function_class_init (ValaClassRegisterFunctionCl
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_class_register_function_real_get_accessibility;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_class_register_function_real_get_type_interface_init_declaration;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_class_register_function_real_get_type_interface_init_statements;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE, g_param_spec_object ("class-reference", "foo", "bar", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_REGISTER_FUNCTION_CLASS_REFERENCE, g_param_spec_object ("class-reference", "class-reference", "class-reference", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_class_register_function_init (ValaClassRegisterFunction * self)
-{
+static void vala_class_register_function_init (ValaClassRegisterFunction * self) {
 	self->priv = VALA_CLASS_REGISTER_FUNCTION_GET_PRIVATE (self);
 }
 
 
-static void vala_class_register_function_dispose (GObject * obj)
-{
+static void vala_class_register_function_dispose (GObject * obj) {
 	ValaClassRegisterFunction * self;
-	ValaClassRegisterFunctionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CLASS_REGISTER_FUNCTION (obj);
-	klass = VALA_CLASS_REGISTER_FUNCTION_CLASS (g_type_class_peek (VALA_TYPE_CLASS_REGISTER_FUNCTION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_class_register_function_parent_class)->dispose (obj);
 }
 
 
-GType vala_class_register_function_get_type (void)
-{
+GType vala_class_register_function_get_type (void) {
 	static GType vala_class_register_function_type_id = 0;
 	if (G_UNLIKELY (vala_class_register_function_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaClassRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClassRegisterFunction), 0, (GInstanceInitFunc) vala_class_register_function_init };
