@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,13 +21,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaarray.h"
+#include <vala/valaarray.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valaarraylengthfield.h>
 #include <vala/valaarrayresizemethod.h>
-#include <vala/valaarraymovemethod.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaarray.h>
 #include <vala/valasourcefile.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasymbol.h>
@@ -70,8 +68,7 @@ static gpointer vala_array_parent_class = NULL;
 static void vala_array_dispose (GObject * obj);
 
 
-ValaArray* vala_array_new (ValaDataType* _element_type, gint _rank, ValaSourceReference* _source_reference)
-{
+ValaArray* vala_array_new (ValaDataType* _element_type, gint _rank, ValaSourceReference* _source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArray * self;
@@ -92,8 +89,7 @@ ValaArray* vala_array_new (ValaDataType* _element_type, gint _rank, ValaSourceRe
 }
 
 
-ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_parameter, gint _rank, ValaSourceReference* _source_reference)
-{
+ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_parameter, gint _rank, ValaSourceReference* _source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArray * self;
@@ -114,11 +110,10 @@ ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_
 }
 
 
-static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type)
-{
+static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type) {
 	ValaArray * self;
 	const char* _tmp4;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	if (self->priv->cname == NULL) {
 		if (vala_array_get_element_type (self) != NULL) {
 			if (vala_data_type_is_reference_type (vala_array_get_element_type (self))) {
@@ -144,42 +139,37 @@ static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type)
 }
 
 
-static gboolean vala_array_real_is_reference_type (ValaDataType* base)
-{
+static gboolean vala_array_real_is_reference_type (ValaDataType* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return TRUE;
 }
 
 
-static char* vala_array_real_get_upper_case_cname (ValaDataType* base, const char* infix)
-{
+static char* vala_array_real_get_upper_case_cname (ValaDataType* base, const char* infix) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return NULL;
 }
 
 
-static char* vala_array_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
-{
+static char* vala_array_real_get_lower_case_cname (ValaSymbol* base, const char* infix) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return NULL;
 }
 
 
-static char* vala_array_real_get_free_function (ValaDataType* base)
-{
+static char* vala_array_real_get_free_function (ValaDataType* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return g_strdup ("g_free");
 }
 
 
-static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base)
-{
+static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	if (vala_array_get_element_type (self) != NULL) {
 		return vala_symbol_get_cheader_filenames (VALA_SYMBOL (vala_array_get_element_type (self)));
 	} else {
@@ -188,38 +178,34 @@ static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base)
 }
 
 
-static char* vala_array_real_get_marshaller_type_name (ValaDataType* base)
-{
+static char* vala_array_real_get_marshaller_type_name (ValaDataType* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return g_strdup ("POINTER");
 }
 
 
-static char* vala_array_real_get_get_value_function (ValaDataType* base)
-{
+static char* vala_array_real_get_get_value_function (ValaDataType* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return g_strdup ("g_value_get_pointer");
 }
 
 
-static char* vala_array_real_get_set_value_function (ValaDataType* base)
-{
+static char* vala_array_real_get_set_value_function (ValaDataType* base) {
 	ValaArray * self;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	return g_strdup ("g_value_set_pointer");
 }
 
 
-static char* vala_array_real_get_type_id (ValaDataType* base)
-{
+static char* vala_array_real_get_type_id (ValaDataType* base) {
 	ValaArray * self;
 	ValaSymbol* _tmp0;
 	gboolean _tmp1;
-	self = ((ValaArray*) base);
+	self = VALA_ARRAY (base);
 	_tmp0 = NULL;
-	if ((_tmp1 = VALA_SYMBOL (vala_array_get_element_type (self)) == (_tmp0 = vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))))), "string")), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+	if ((_tmp1 = VALA_SYMBOL (vala_array_get_element_type (self)) == (_tmp0 = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))))), "string")), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 		return g_strdup ("G_TYPE_STRV");
 	} else {
 		return NULL;
@@ -227,8 +213,7 @@ static char* vala_array_real_get_type_id (ValaDataType* base)
 }
 
 
-ValaArrayLengthField* vala_array_get_length_field (ValaArray* self)
-{
+ValaArrayLengthField* vala_array_get_length_field (ValaArray* self) {
 	ValaArrayLengthField* _tmp3;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->length_field == NULL) {
@@ -237,14 +222,14 @@ ValaArrayLengthField* vala_array_get_length_field (ValaArray* self)
 		ValaTypeReference* _tmp1;
 		ValaDataType* _tmp2;
 		_tmp0 = NULL;
-		self->priv->length_field = (_tmp0 = vala_array_length_field_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), _tmp0);
+		self->priv->length_field = (_tmp0 = vala_array_length_field_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), _tmp0);
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->length_field), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
 		_tmp1 = NULL;
 		vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), (_tmp1 = vala_type_reference_new ()));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		_tmp2 = NULL;
-		vala_type_reference_set_data_type (vala_field_get_type_reference (((ValaField*) self->priv->length_field)), (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		vala_type_reference_set_data_type (vala_field_get_type_reference (VALA_FIELD (self->priv->length_field)), (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int"))));
 		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		(root_symbol = (g_object_unref (root_symbol), NULL));
 	}
@@ -253,8 +238,7 @@ ValaArrayLengthField* vala_array_get_length_field (ValaArray* self)
 }
 
 
-ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self)
-{
+ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self) {
 	ValaArrayResizeMethod* _tmp4;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->resize_method == NULL) {
@@ -265,16 +249,16 @@ ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self)
 		ValaDataType* _tmp2;
 		ValaFormalParameter* _tmp3;
 		_tmp0 = NULL;
-		self->priv->resize_method = (_tmp0 = vala_array_resize_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), _tmp0);
+		self->priv->resize_method = (_tmp0 = vala_array_resize_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), _tmp0);
 		_tmp1 = NULL;
 		vala_method_set_return_type (VALA_METHOD (self->priv->resize_method), (_tmp1 = vala_type_reference_new ()));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->resize_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->resize_method), "g_renew");
-		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
 		int_type = vala_type_reference_new ();
 		_tmp2 = NULL;
-		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int"))));
 		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		_tmp3 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->resize_method), (_tmp3 = vala_formal_parameter_new ("length", int_type, NULL)));
@@ -288,8 +272,7 @@ ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self)
 }
 
 
-ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self)
-{
+ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self) {
 	ValaArrayMoveMethod* _tmp6;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	if (self->priv->move_method == NULL) {
@@ -302,16 +285,16 @@ ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self)
 		ValaFormalParameter* _tmp4;
 		ValaFormalParameter* _tmp5;
 		_tmp0 = NULL;
-		self->priv->move_method = (_tmp0 = vala_array_move_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), _tmp0);
+		self->priv->move_method = (_tmp0 = vala_array_move_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), _tmp0);
 		_tmp1 = NULL;
 		vala_method_set_return_type (VALA_METHOD (self->priv->move_method), (_tmp1 = vala_type_reference_new ()));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		vala_symbol_set_access (VALA_SYMBOL (self->priv->move_method), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_method_set_cname (VALA_METHOD (self->priv->move_method), "_vala_array_move");
-		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))));
 		int_type = vala_type_reference_new ();
 		_tmp2 = NULL;
-		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		vala_type_reference_set_data_type (int_type, (_tmp2 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "int"))));
 		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		_tmp3 = NULL;
 		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (_tmp3 = vala_formal_parameter_new ("src", int_type, NULL)));
@@ -330,50 +313,43 @@ ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self)
 }
 
 
-ValaDataType* vala_array_get_element_type (ValaArray* self)
-{
+ValaDataType* vala_array_get_element_type (ValaArray* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	return self->priv->_element_type;
 }
 
 
-void vala_array_set_element_type (ValaArray* self, ValaDataType* value)
-{
+void vala_array_set_element_type (ValaArray* self, ValaDataType* value) {
 	g_return_if_fail (VALA_IS_ARRAY (self));
 	self->priv->_element_type = value;
 }
 
 
-ValaTypeParameter* vala_array_get_element_type_parameter (ValaArray* self)
-{
+ValaTypeParameter* vala_array_get_element_type_parameter (ValaArray* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
 	return self->priv->_element_type_parameter;
 }
 
 
-void vala_array_set_element_type_parameter (ValaArray* self, ValaTypeParameter* value)
-{
+void vala_array_set_element_type_parameter (ValaArray* self, ValaTypeParameter* value) {
 	g_return_if_fail (VALA_IS_ARRAY (self));
 	self->priv->_element_type_parameter = value;
 }
 
 
-gint vala_array_get_rank (ValaArray* self)
-{
+gint vala_array_get_rank (ValaArray* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY (self), 0);
 	return self->priv->_rank;
 }
 
 
-void vala_array_set_rank (ValaArray* self, gint value)
-{
+void vala_array_set_rank (ValaArray* self, gint value) {
 	g_return_if_fail (VALA_IS_ARRAY (self));
 	self->priv->_rank = value;
 }
 
 
-static GObject * vala_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
-{
+static GObject * vala_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	ValaArrayClass * klass;
 	GObjectClass * parent_class;
@@ -402,31 +378,30 @@ static GObject * vala_array_constructor (GType type, guint n_construct_propertie
 		if (vala_array_get_element_type (self) != NULL) {
 			char* _tmp0;
 			_tmp0 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp0 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type (self))))));
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp0 = g_strdup_printf ("%s[", vala_symbol_get_name (VALA_SYMBOL (vala_array_get_element_type (self))))));
 			(_tmp0 = (g_free (_tmp0), NULL));
 		} else {
 			char* _tmp1;
 			_tmp1 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp1 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type_parameter (self))))));
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp1 = g_strdup_printf ("%s[", vala_symbol_get_name (VALA_SYMBOL (vala_array_get_element_type_parameter (self))))));
 			(_tmp1 = (g_free (_tmp1), NULL));
 		}
 		while (i > 0) {
 			char* _tmp2;
 			_tmp2 = NULL;
-			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp2 = g_strdup_printf ("%s,", vala_symbol_get_name (((ValaSymbol*) self)))));
+			vala_symbol_set_name (VALA_SYMBOL (self), (_tmp2 = g_strdup_printf ("%s,", vala_symbol_get_name (VALA_SYMBOL (self)))));
 			(_tmp2 = (g_free (_tmp2), NULL));
 			i--;
 		}
 		_tmp3 = NULL;
-		vala_symbol_set_name (VALA_SYMBOL (self), (_tmp3 = g_strdup_printf ("%s]", vala_symbol_get_name (((ValaSymbol*) self)))));
+		vala_symbol_set_name (VALA_SYMBOL (self), (_tmp3 = g_strdup_printf ("%s]", vala_symbol_get_name (VALA_SYMBOL (self)))));
 		(_tmp3 = (g_free (_tmp3), NULL));
 	}
 	return obj;
 }
 
 
-static void vala_array_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_array_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaArray * self;
 	self = VALA_ARRAY (object);
 	switch (property_id) {
@@ -446,8 +421,7 @@ static void vala_array_get_property (GObject * object, guint property_id, GValue
 }
 
 
-static void vala_array_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_array_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaArray * self;
 	self = VALA_ARRAY (object);
 	switch (property_id) {
@@ -467,8 +441,7 @@ static void vala_array_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_array_class_init (ValaArrayClass * klass)
-{
+static void vala_array_class_init (ValaArrayClass * klass) {
 	vala_array_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaArrayPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_array_get_property;
@@ -485,36 +458,29 @@ static void vala_array_class_init (ValaArrayClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_array_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_array_real_get_set_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_array_real_get_type_id;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE, g_param_spec_object ("element-type", "foo", "bar", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE_PARAMETER, g_param_spec_object ("element-type-parameter", "foo", "bar", VALA_TYPE_TYPE_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_RANK, g_param_spec_int ("rank", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_ELEMENT_TYPE_PARAMETER, g_param_spec_object ("element-type-parameter", "element-type-parameter", "element-type-parameter", VALA_TYPE_TYPE_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_array_init (ValaArray * self)
-{
+static void vala_array_init (ValaArray * self) {
 	self->priv = VALA_ARRAY_GET_PRIVATE (self);
 }
 
 
-static void vala_array_dispose (GObject * obj)
-{
+static void vala_array_dispose (GObject * obj) {
 	ValaArray * self;
-	ValaArrayClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_ARRAY (obj);
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL)));
 	(self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL)));
 	(self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL)));
-	klass = VALA_ARRAY_CLASS (g_type_class_peek (VALA_TYPE_ARRAY));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_array_parent_class)->dispose (obj);
 }
 
 
-GType vala_array_get_type (void)
-{
+GType vala_array_get_type (void) {
 	static GType vala_array_type_id = 0;
 	if (G_UNLIKELY (vala_array_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArray), 0, (GInstanceInitFunc) vala_array_init };
