@@ -1,11 +1,11 @@
 /* valaassignment.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,12 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAASSIGNMENT_H__
-#define __VALAASSIGNMENT_H__
+#ifndef __VALA_VALAASSIGNMENT_H__
+#define __VALA_VALAASSIGNMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valaexpression.h>
-#include <vala/valaassignment.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -67,7 +66,7 @@ typedef enum  {
 	VALA_ASSIGNMENT_OPERATOR_SHIFT_RIGHT
 } ValaAssignmentOperator;
 
-ValaAssignment* vala_assignment_new (ValaExpression* _left, ValaExpression* _right, ValaAssignmentOperator _op, ValaSourceReference* _source);
+ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right, ValaAssignmentOperator operator, ValaSourceReference* source_reference);
 ValaExpression* vala_assignment_get_left (ValaAssignment* self);
 void vala_assignment_set_left (ValaAssignment* self, ValaExpression* value);
 ValaAssignmentOperator vala_assignment_get_operator (ValaAssignment* self);
