@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,8 +21,8 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALAATTRIBUTEPROCESSOR_H__
-#define __VALAATTRIBUTEPROCESSOR_H__
+#ifndef __VALA_VALAATTRIBUTEPROCESSOR_H__
+#define __VALA_VALAATTRIBUTEPROCESSOR_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -34,7 +34,6 @@
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
-#include <vala/valaflags.h>
 #include <vala/valamethod.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valaproperty.h>
@@ -68,7 +67,8 @@ struct _ValaAttributeProcessorClass {
 };
 
 void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeContext* context);
-GType vala_attribute_processor_get_type ();
+ValaAttributeProcessor* vala_attribute_processor_new (void);
+GType vala_attribute_processor_get_type (void);
 
 G_END_DECLS
 
