@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACODENODE_H__
-#define __VALACODENODE_H__
+#ifndef __VALA_VALACODENODE_H__
+#define __VALA_VALACODENODE_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -43,20 +44,16 @@ typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
-typedef struct _ValaMethod ValaMethod;
-typedef struct _ValaMethodClass ValaMethodClass;
-typedef struct _ValaMember ValaMember;
-typedef struct _ValaMemberClass ValaMemberClass;
+typedef struct _ValaNamespace ValaNamespace;
+typedef struct _ValaNamespaceClass ValaNamespaceClass;
 typedef struct _ValaSymbol ValaSymbol;
 typedef struct _ValaSymbolClass ValaSymbolClass;
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
-typedef struct _ValaInvokable ValaInvokable;
-typedef struct _ValaInvokableIface ValaInvokableIface;
-typedef struct _ValaTypeReference ValaTypeReference;
-typedef struct _ValaTypeReferenceClass ValaTypeReferenceClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
 typedef struct _ValaDataType ValaDataType;
 typedef struct _ValaDataTypeClass ValaDataTypeClass;
 typedef struct _ValaPointer ValaPointer;
@@ -69,10 +66,16 @@ typedef struct _ValaArrayLengthField ValaArrayLengthField;
 typedef struct _ValaArrayLengthFieldClass ValaArrayLengthFieldClass;
 typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
+typedef struct _ValaInvokable ValaInvokable;
+typedef struct _ValaInvokableIface ValaInvokableIface;
+typedef struct _ValaTypeReference ValaTypeReference;
+typedef struct _ValaTypeReferenceClass ValaTypeReferenceClass;
 typedef struct _ValaArrayResizeMethod ValaArrayResizeMethod;
 typedef struct _ValaArrayResizeMethodClass ValaArrayResizeMethodClass;
-typedef struct _ValaArrayMoveMethod ValaArrayMoveMethod;
-typedef struct _ValaArrayMoveMethodClass ValaArrayMoveMethodClass;
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaFormalParameter ValaFormalParameter;
 typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 typedef struct _ValaBlock ValaBlock;
@@ -81,10 +84,6 @@ typedef struct _ValaStatement ValaStatement;
 typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaVariableDeclarator ValaVariableDeclarator;
 typedef struct _ValaVariableDeclaratorClass ValaVariableDeclaratorClass;
-typedef struct _ValaNamespace ValaNamespace;
-typedef struct _ValaNamespaceClass ValaNamespaceClass;
-typedef struct _ValaClass ValaClass;
-typedef struct _ValaClassClass ValaClassClass;
 typedef struct _ValaConstant ValaConstant;
 typedef struct _ValaConstantClass ValaConstantClass;
 typedef struct _ValaProperty ValaProperty;
@@ -107,14 +106,8 @@ typedef struct _ValaEnum ValaEnum;
 typedef struct _ValaEnumClass ValaEnumClass;
 typedef struct _ValaEnumValue ValaEnumValue;
 typedef struct _ValaEnumValueClass ValaEnumValueClass;
-typedef struct _ValaNamespaceReference ValaNamespaceReference;
-typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
-typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
-typedef struct _ValaSourceFileCycleClass ValaSourceFileCycleClass;
 typedef struct _ValaCreationMethod ValaCreationMethod;
 typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
-typedef struct _ValaNamedArgument ValaNamedArgument;
-typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;
 typedef struct _ValaEmptyStatement ValaEmptyStatement;
 typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;
 typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
@@ -187,6 +180,8 @@ typedef struct _ValaPostfixExpression ValaPostfixExpression;
 typedef struct _ValaPostfixExpressionClass ValaPostfixExpressionClass;
 typedef struct _ValaObjectCreationExpression ValaObjectCreationExpression;
 typedef struct _ValaObjectCreationExpressionClass ValaObjectCreationExpressionClass;
+typedef struct _ValaMemberInitializer ValaMemberInitializer;
+typedef struct _ValaMemberInitializerClass ValaMemberInitializerClass;
 typedef struct _ValaSizeofExpression ValaSizeofExpression;
 typedef struct _ValaSizeofExpressionClass ValaSizeofExpressionClass;
 typedef struct _ValaTypeofExpression ValaTypeofExpression;
@@ -209,6 +204,14 @@ typedef struct _ValaLambdaExpression ValaLambdaExpression;
 typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
 typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
+typedef struct _ValaCodeGenerator ValaCodeGenerator;
+typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
+typedef struct _ValaNamespaceReference ValaNamespaceReference;
+typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
+typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
+typedef struct _ValaSourceFileCycleClass ValaSourceFileCycleClass;
+typedef struct _ValaNamedArgument ValaNamedArgument;
+typedef struct _ValaNamedArgumentClass ValaNamedArgumentClass;
 typedef struct _ValaAttribute ValaAttribute;
 typedef struct _ValaAttributeClass ValaAttributeClass;
 
@@ -251,6 +254,8 @@ ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
+ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self);
+void vala_code_node_set_code_binding (ValaCodeNode* self, ValaCodeBinding* value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
