@@ -1,11 +1,11 @@
 /* valadeclarationstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALADECLARATIONSTATEMENT_H__
-#define __VALADECLARATIONSTATEMENT_H__
+#ifndef __VALA_VALADECLARATIONSTATEMENT_H__
+#define __VALA_VALADECLARATIONSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -44,17 +44,17 @@ typedef struct _ValaDeclarationStatementPrivate ValaDeclarationStatementPrivate;
  * Represents a local variable declaration statement in the source code.
  */
 struct _ValaDeclarationStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaDeclarationStatementPrivate * priv;
 };
 struct _ValaDeclarationStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
 ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source);
 ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self);
 void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value);
-GType vala_declaration_statement_get_type ();
+GType vala_declaration_statement_get_type (void);
 
 G_END_DECLS
 
