@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valadestructor.h"
+#include <vala/valadestructor.h>
 #include <vala/valablock.h>
 #include <vala/valasourcereference.h>
-#include <vala/valadestructor.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaDestructorPrivate {
@@ -48,8 +47,7 @@ static void vala_destructor_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created destructor
  */
-ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference)
-{
+ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
 	ValaDestructor * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_DESTRUCTOR, 0, NULL);
@@ -58,19 +56,17 @@ ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference)
 }
 
 
-static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
-	self = ((ValaDestructor*) base);
+	self = VALA_DESTRUCTOR (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_destructor (visitor, self);
 }
 
 
-static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDestructor * self;
-	self = ((ValaDestructor*) base);
+	self = VALA_DESTRUCTOR (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_destructor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_destructor_get_body (self)), visitor);
@@ -78,15 +74,13 @@ static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVi
 }
 
 
-ValaBlock* vala_destructor_get_body (ValaDestructor* self)
-{
+ValaBlock* vala_destructor_get_body (ValaDestructor* self) {
 	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value)
-{
+void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
@@ -96,22 +90,19 @@ void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value)
 }
 
 
-gboolean vala_destructor_get_instance (ValaDestructor* self)
-{
+gboolean vala_destructor_get_instance (ValaDestructor* self) {
 	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), FALSE);
 	return self->priv->_instance;
 }
 
 
-void vala_destructor_set_instance (ValaDestructor* self, gboolean value)
-{
+void vala_destructor_set_instance (ValaDestructor* self, gboolean value) {
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
 	self->priv->_instance = value;
 }
 
 
-static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (object);
 	switch (property_id) {
@@ -128,8 +119,7 @@ static void vala_destructor_get_property (GObject * object, guint property_id, G
 }
 
 
-static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaDestructor * self;
 	self = VALA_DESTRUCTOR (object);
 	switch (property_id) {
@@ -146,8 +136,7 @@ static void vala_destructor_set_property (GObject * object, guint property_id, c
 }
 
 
-static void vala_destructor_class_init (ValaDestructorClass * klass)
-{
+static void vala_destructor_class_init (ValaDestructorClass * klass) {
 	vala_destructor_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
@@ -155,33 +144,26 @@ static void vala_destructor_class_init (ValaDestructorClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_destructor_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_destructor_init (ValaDestructor * self)
-{
+static void vala_destructor_init (ValaDestructor * self) {
 	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
 }
 
 
-static void vala_destructor_dispose (GObject * obj)
-{
+static void vala_destructor_dispose (GObject * obj) {
 	ValaDestructor * self;
-	ValaDestructorClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_DESTRUCTOR (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	klass = VALA_DESTRUCTOR_CLASS (g_type_class_peek (VALA_TYPE_DESTRUCTOR));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_destructor_parent_class)->dispose (obj);
 }
 
 
-GType vala_destructor_get_type (void)
-{
+GType vala_destructor_get_type (void) {
 	static GType vala_destructor_type_id = 0;
 	if (G_UNLIKELY (vala_destructor_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_init };
