@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,19 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
-#include "valaformalparameter.h"
+#include <vala/valaformalparameter.h>
 #include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaformalparameter.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacallback.h>
 
 struct _ValaFormalParameterPrivate {
-	char* _name;
 	ValaTypeReference* _type_reference;
 	gboolean _ellipsis;
 	ValaExpression* _default_expression;
@@ -42,7 +38,6 @@ struct _ValaFormalParameterPrivate {
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
 	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY,
-	VALA_FORMAL_PARAMETER_NAME,
 	VALA_FORMAL_PARAMETER_TYPE_REFERENCE,
 	VALA_FORMAL_PARAMETER_ELLIPSIS,
 	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
@@ -51,9 +46,10 @@ enum  {
 };
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static GList* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
+static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base);
 static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base);
+static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
 static ValaInvokableIface* vala_formal_parameter_vala_invokable_parent_iface = NULL;
 static void vala_formal_parameter_dispose (GObject * obj);
@@ -67,20 +63,15 @@ static void vala_formal_parameter_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created formal parameter
  */
-ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source) {
 	ValaFormalParameter * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (type == NULL || VALA_IS_TYPE_REFERENCE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), _name);
+	vala_formal_parameter_set_type_reference (self, type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -89,23 +80,17 @@ ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeRefer
  * Creates a new ellipsis parameter representing an indefinite number of
  * parameters.
  */
-ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source) {
 	ValaFormalParameter * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "ellipsis", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, TRUE), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
+	vala_formal_parameter_set_ellipsis (self, TRUE);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
-static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
@@ -113,8 +98,7 @@ static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisit
 }
 
 
-static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
@@ -127,154 +111,137 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 }
 
 
-static GList* vala_formal_parameter_real_get_parameters (ValaInvokable* base)
-{
+static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base) {
 	ValaFormalParameter * self;
-	ValaCallback* __temp1;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	GList* __temp2;
+	GeeCollection* _tmp2;
 	self = VALA_FORMAL_PARAMETER (base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
 		return NULL;
 	}
-	__temp1 = NULL;
-	cb = (__temp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-	__temp2 = NULL;
-	return (__temp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp2);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
 
-static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base)
-{
+static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base) {
 	ValaFormalParameter * self;
-	ValaCallback* __temp4;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	ValaTypeReference* __temp5;
-	ValaTypeReference* __temp6;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp3;
 	self = VALA_FORMAL_PARAMETER (base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
-		return VALA_TYPE_REFERENCE (NULL);
+		return NULL;
 	}
-	__temp4 = NULL;
-	cb = (__temp4 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
-	__temp5 = NULL;
-	__temp6 = NULL;
-	return (__temp6 = (__temp5 = vala_callback_get_return_type (cb), (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp6);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
 
-static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base)
-{
+static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
 	return (VALA_IS_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))));
 }
 
 
-char* vala_formal_parameter_get_name (ValaFormalParameter* self)
-{
-	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_formal_parameter_set_name (ValaFormalParameter* self, const char* value)
-{
-	char* __temp9;
-	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	__temp9 = NULL;
-	self->priv->_name = (__temp9 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp9);
-}
-
-
-ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self)
-{
+ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_type_reference;
 }
 
 
-void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value)
-{
-	ValaTypeReference* __temp12;
-	ValaTypeReference* __temp11;
+void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value) {
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	__temp12 = NULL;
-	__temp11 = NULL;
-	self->priv->_type_reference = (__temp12 = (__temp11 = value, (__temp11 == NULL ? NULL : g_object_ref (__temp11))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp12);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp2);
 }
 
 
-gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self)
-{
+gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), FALSE);
 	return self->priv->_ellipsis;
 }
 
 
-void vala_formal_parameter_set_ellipsis (ValaFormalParameter* self, gboolean value)
-{
+void vala_formal_parameter_set_ellipsis (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_ellipsis = value;
 }
 
 
-ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParameter* self)
-{
+ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_default_expression;
 }
 
 
-void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value)
-{
-	ValaExpression* __temp16;
-	ValaExpression* __temp15;
+void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	__temp16 = NULL;
-	__temp15 = NULL;
-	self->priv->_default_expression = (__temp16 = (__temp15 = value, (__temp15 == NULL ? NULL : g_object_ref (__temp15))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), __temp16);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
 }
 
 
-gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self)
-{
+gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), FALSE);
 	return self->priv->_no_array_length;
 }
 
 
-void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value)
-{
+void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_no_array_length = value;
 }
 
 
-gboolean vala_formal_parameter_get_construct_parameter (ValaFormalParameter* self)
-{
+gboolean vala_formal_parameter_get_construct_parameter (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), FALSE);
 	return self->priv->_construct_parameter;
 }
 
 
-void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, gboolean value)
-{
+void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, gboolean value) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
 	self->priv->_construct_parameter = value;
 }
 
 
-static void vala_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	ValaFormalParameterClass * klass;
+	GObjectClass * parent_class;
+	ValaFormalParameter * self;
+	klass = VALA_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_FORMAL_PARAMETER));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = VALA_FORMAL_PARAMETER (obj);
+	{
+		vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	}
+	return obj;
+}
+
+
+static void vala_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_NAME:
-		g_value_set_string (value, vala_formal_parameter_get_name (self));
-		break;
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		g_value_set_object (value, vala_formal_parameter_get_type_reference (self));
 		break;
@@ -290,18 +257,17 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		g_value_set_boolean (value, vala_formal_parameter_get_construct_parameter (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_formal_parameter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_formal_parameter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_NAME:
-		vala_formal_parameter_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		vala_formal_parameter_set_type_reference (self, g_value_get_object (value));
 		break;
@@ -317,30 +283,31 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		vala_formal_parameter_set_construct_parameter (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
-{
+static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass) {
 	vala_formal_parameter_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaFormalParameterPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_formal_parameter_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_formal_parameter_set_property;
+	G_OBJECT_CLASS (klass)->constructor = vala_formal_parameter_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER, g_param_spec_boolean ("construct-parameter", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "ellipsis", "ellipsis", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER, g_param_spec_boolean ("construct-parameter", "construct-parameter", "construct-parameter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_formal_parameter_vala_invokable_interface_init (ValaInvokableIface * iface)
-{
+static void vala_formal_parameter_vala_invokable_interface_init (ValaInvokableIface * iface) {
 	vala_formal_parameter_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_parameters = vala_formal_parameter_real_get_parameters;
 	iface->get_return_type = vala_formal_parameter_real_get_return_type;
@@ -348,34 +315,26 @@ static void vala_formal_parameter_vala_invokable_interface_init (ValaInvokableIf
 }
 
 
-static void vala_formal_parameter_init (ValaFormalParameter * self)
-{
+static void vala_formal_parameter_init (ValaFormalParameter * self) {
 	self->priv = VALA_FORMAL_PARAMETER_GET_PRIVATE (self);
 }
 
 
-static void vala_formal_parameter_dispose (GObject * obj)
-{
+static void vala_formal_parameter_dispose (GObject * obj) {
 	ValaFormalParameter * self;
-	ValaFormalParameterClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
-	klass = VALA_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_FORMAL_PARAMETER));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_formal_parameter_parent_class)->dispose (obj);
 }
 
 
-GType vala_formal_parameter_get_type ()
-{
+GType vala_formal_parameter_get_type (void) {
 	static GType vala_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_init };
 		static const GInterfaceInfo vala_invokable_info = { (GInterfaceInitFunc) vala_formal_parameter_vala_invokable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaFormalParameter", &g_define_type_info, 0);
+		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_formal_parameter_type_id, VALA_TYPE_INVOKABLE, &vala_invokable_info);
 	}
 	return vala_formal_parameter_type_id;
