@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaliteralexpression.h"
+#include <vala/valaliteralexpression.h>
 #include <vala/valaliteral.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaliteralexpression.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaLiteralExpressionPrivate {
@@ -47,8 +46,7 @@ static void vala_literal_expression_dispose (GObject * obj);
  * @param source  reference to source code
  * @return        newly created literal expression
  */
-ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaSourceReference* source)
-{
+ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaLiteralExpression * self;
@@ -68,68 +66,67 @@ ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaS
 }
 
 
-static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_literal_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLiteralExpression * self;
-	self = ((ValaLiteralExpression*) base);
+	self = VALA_LITERAL_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_literal_expression_get_literal (self)), visitor);
 	vala_code_visitor_visit_literal_expression (visitor, self);
 }
 
 
-static char* vala_literal_expression_real_to_string (ValaCodeNode* base)
-{
+static char* vala_literal_expression_real_to_string (ValaCodeNode* base) {
 	ValaLiteralExpression * self;
-	self = ((ValaLiteralExpression*) base);
+	self = VALA_LITERAL_EXPRESSION (base);
 	return vala_code_node_to_string (VALA_CODE_NODE (vala_literal_expression_get_literal (self)));
 }
 
 
-ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self)
-{
+ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self) {
 	g_return_val_if_fail (VALA_IS_LITERAL_EXPRESSION (self), NULL);
 	return self->priv->_literal;
 }
 
 
-void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value)
-{
-	ValaLiteral* __temp3;
-	ValaLiteral* __temp2;
+void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value) {
+	ValaLiteral* _tmp2;
+	ValaLiteral* _tmp1;
 	g_return_if_fail (VALA_IS_LITERAL_EXPRESSION (self));
-	__temp3 = NULL;
-	__temp2 = NULL;
-	self->priv->_literal = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_literal = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL))), _tmp2);
 }
 
 
-static void vala_literal_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_literal_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaLiteralExpression * self;
 	self = VALA_LITERAL_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_LITERAL_EXPRESSION_LITERAL:
 		g_value_set_object (value, vala_literal_expression_get_literal (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_literal_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_literal_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaLiteralExpression * self;
 	self = VALA_LITERAL_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_LITERAL_EXPRESSION_LITERAL:
 		vala_literal_expression_set_literal (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_literal_expression_class_init (ValaLiteralExpressionClass * klass)
-{
+static void vala_literal_expression_class_init (ValaLiteralExpressionClass * klass) {
 	vala_literal_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaLiteralExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_literal_expression_get_property;
@@ -137,31 +134,24 @@ static void vala_literal_expression_class_init (ValaLiteralExpressionClass * kla
 	G_OBJECT_CLASS (klass)->dispose = vala_literal_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_literal_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_literal_expression_real_to_string;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_EXPRESSION_LITERAL, g_param_spec_object ("literal", "foo", "bar", VALA_TYPE_LITERAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_LITERAL_EXPRESSION_LITERAL, g_param_spec_object ("literal", "literal", "literal", VALA_TYPE_LITERAL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
-static void vala_literal_expression_init (ValaLiteralExpression * self)
-{
+static void vala_literal_expression_init (ValaLiteralExpression * self) {
 	self->priv = VALA_LITERAL_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_literal_expression_dispose (GObject * obj)
-{
+static void vala_literal_expression_dispose (GObject * obj) {
 	ValaLiteralExpression * self;
-	ValaLiteralExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_LITERAL_EXPRESSION (obj);
 	(self->priv->_literal == NULL ? NULL : (self->priv->_literal = (g_object_unref (self->priv->_literal), NULL)));
-	klass = VALA_LITERAL_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_LITERAL_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_literal_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_literal_expression_get_type (void)
-{
+GType vala_literal_expression_get_type (void) {
 	static GType vala_literal_expression_type_id = 0;
 	if (G_UNLIKELY (vala_literal_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteralExpression), 0, (GInstanceInitFunc) vala_literal_expression_init };
