@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,14 +21,13 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#ifndef __VALAMEMORYMANAGER_H__
-#define __VALAMEMORYMANAGER_H__
+#ifndef __VALA_VALAMEMORYMANAGER_H__
+#define __VALA_VALAMEMORYMANAGER_H__
 
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
-#include <vala/valaexpression.h>
 #include <vala/valasourcefile.h>
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
@@ -41,16 +40,22 @@
 #include <vala/valaconstructor.h>
 #include <vala/valadestructor.h>
 #include <vala/valanamedargument.h>
+#include <vala/valablock.h>
 #include <vala/valavariabledeclarator.h>
+#include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
+#include <vala/valaswitchsection.h>
+#include <vala/valaforeachstatement.h>
 #include <vala/valareturnstatement.h>
 #include <vala/valathrowstatement.h>
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
+#include <vala/valaarraycreationexpression.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valaobjectcreationexpression.h>
 #include <vala/valabinaryexpression.h>
+#include <vala/valalambdaexpression.h>
 #include <vala/valaassignment.h>
 
 G_BEGIN_DECLS
@@ -80,6 +85,7 @@ struct _ValaMemoryManagerClass {
 };
 
 void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* context);
+ValaMemoryManager* vala_memory_manager_new (void);
 GType vala_memory_manager_get_type (void);
 
 G_END_DECLS
