@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,7 +21,7 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#include "valamethod.h"
+#include <vala/valamethod.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
@@ -29,7 +29,6 @@
 #include <gee/iterator.h>
 #include <vala/valatypereference.h>
 #include <vala/valablock.h>
-#include <vala/valamethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
@@ -45,7 +44,6 @@ struct _ValaMethodPrivate {
 	gboolean _overrides;
 	gboolean _returns_modified_pointer;
 	gboolean _instance_last;
-	gboolean _instance_by_reference;
 	ValaMethod* _base_method;
 	ValaMethod* _base_interface_method;
 	ValaFormalParameter* _this_parameter;
@@ -71,7 +69,6 @@ enum  {
 	VALA_METHOD_OVERRIDES,
 	VALA_METHOD_RETURNS_MODIFIED_POINTER,
 	VALA_METHOD_INSTANCE_LAST,
-	VALA_METHOD_INSTANCE_BY_REFERENCE,
 	VALA_METHOD_BASE_METHOD,
 	VALA_METHOD_BASE_INTERFACE_METHOD,
 	VALA_METHOD_THIS_PARAMETER,
@@ -99,8 +96,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
  * @param source      reference to source code
  * @return            newly created method
  */
-ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference)
-{
+ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference) {
 	ValaMethod * self;
 	g_return_val_if_fail (return_type == NULL || VALA_IS_TYPE_REFERENCE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
@@ -117,8 +113,7 @@ ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, V
  *
  * @param param a formal parameter
  */
-void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param)
-{
+void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_method_get_no_array_length (self)) {
@@ -126,50 +121,45 @@ void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param)
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 	if (!vala_formal_parameter_get_ellipsis (param)) {
-		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) param)), VALA_SYMBOL (param));
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
 	}
 }
 
 
-static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base)
-{
+static GeeCollection* vala_method_real_get_parameters (ValaInvokable* base) {
 	ValaMethod * self;
-	self = ((ValaMethod*) base);
+	self = VALA_METHOD (base);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->parameters)));
 }
 
 
-static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base)
-{
+static ValaTypeReference* vala_method_real_get_return_type (ValaInvokable* base) {
 	ValaMethod * self;
 	ValaTypeReference* _tmp0;
-	self = ((ValaMethod*) base);
+	self = VALA_METHOD (base);
 	_tmp0 = NULL;
 	return (_tmp0 = vala_method_get_return_type (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
 
 
-static gboolean vala_method_real_is_invokable (ValaInvokable* base)
-{
+static gboolean vala_method_real_is_invokable (ValaInvokable* base) {
 	ValaMethod * self;
-	self = ((ValaMethod*) base);
+	self = VALA_METHOD (base);
 	return TRUE;
 }
 
 
-static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
-	self = ((ValaMethod*) base);
+	self = VALA_METHOD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_method (visitor, self);
 }
 
 
-static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
-	self = ((ValaMethod*) base);
+	self = VALA_METHOD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_method_get_return_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_return_type (self)), visitor);
@@ -215,8 +205,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
  *
  * @return the name to be used in C code
  */
-char* vala_method_get_cname (ValaMethod* self)
-{
+char* vala_method_get_cname (ValaMethod* self) {
 	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (self->priv->cname == NULL) {
@@ -235,27 +224,25 @@ char* vala_method_get_cname (ValaMethod* self)
  *
  * @return the name to be used in C code by default
  */
-static char* vala_method_real_get_default_cname (ValaMethod* self)
-{
+static char* vala_method_real_get_default_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	if (g_str_has_prefix (vala_symbol_get_name (((ValaSymbol*) self)), "_")) {
+	if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (self)), "_")) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		return (_tmp1 = g_strdup_printf ("_%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), g_utf8_offset_to_pointer (vala_symbol_get_name (((ValaSymbol*) self)), 1)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+		return (_tmp1 = g_strdup_printf ("_%s%s", (_tmp0 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (self)), 1)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 	} else {
 		char* _tmp3;
 		char* _tmp4;
 		_tmp3 = NULL;
 		_tmp4 = NULL;
-		return (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4);
+		return (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp3 = (g_free (_tmp3), NULL)), _tmp4);
 	}
 }
 
 
-char* vala_method_get_default_cname (ValaMethod* self)
-{
+char* vala_method_get_default_cname (ValaMethod* self) {
 	return VALA_METHOD_GET_CLASS (self)->get_default_cname (self);
 }
 
@@ -266,15 +253,14 @@ char* vala_method_get_default_cname (ValaMethod* self)
  *
  * @return the name to be used in C code
  */
-char* vala_method_get_real_cname (ValaMethod* self)
-{
+char* vala_method_get_real_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (vala_method_get_base_method (self) != NULL || vala_method_get_base_interface_method (self) != NULL) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		return (_tmp1 = g_strdup_printf ("%s_real_%s", (_tmp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), vala_symbol_get_name (((ValaSymbol*) self))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+		return (_tmp1 = g_strdup_printf ("%s_real_%s", (_tmp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), NULL)), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 	} else {
 		return vala_method_get_cname (self);
 	}
@@ -286,8 +272,7 @@ char* vala_method_get_real_cname (ValaMethod* self)
  *
  * @param cname the name to be used in C code
  */
-void vala_method_set_cname (ValaMethod* self, const char* cname)
-{
+void vala_method_set_cname (ValaMethod* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_METHOD (self));
@@ -297,8 +282,7 @@ void vala_method_set_cname (ValaMethod* self, const char* cname)
 }
 
 
-static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a)
-{
+static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
@@ -348,13 +332,12 @@ static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute
 /**
  * Process all associated attributes.
  */
-void vala_method_process_attributes (ValaMethod* self)
-{
+void vala_method_process_attributes (ValaMethod* self) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = ((ValaCodeNode*) self)->attributes;
+		a_collection = VALA_CODE_NODE (self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
@@ -370,21 +353,17 @@ void vala_method_process_attributes (ValaMethod* self)
 						if (g_utf8_collate (vala_attribute_get_name (a), "InstanceLast") == 0) {
 							vala_method_set_instance_last (self, TRUE);
 						} else {
-							if (g_utf8_collate (vala_attribute_get_name (a), "InstanceByReference") == 0) {
-								vala_method_set_instance_by_reference (self, TRUE);
+							if (g_utf8_collate (vala_attribute_get_name (a), "FloatingReference") == 0) {
+								vala_type_reference_set_floating_reference (vala_method_get_return_type (self), TRUE);
 							} else {
-								if (g_utf8_collate (vala_attribute_get_name (a), "FloatingReference") == 0) {
-									vala_type_reference_set_floating_reference (vala_method_get_return_type (self), TRUE);
+								if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
+									vala_method_set_no_array_length (self, TRUE);
 								} else {
-									if (g_utf8_collate (vala_attribute_get_name (a), "NoArrayLength") == 0) {
-										vala_method_set_no_array_length (self, TRUE);
+									if (g_utf8_collate (vala_attribute_get_name (a), "PrintfFormat") == 0) {
+										vala_method_set_printf_format (self, TRUE);
 									} else {
-										if (g_utf8_collate (vala_attribute_get_name (a), "PrintfFormat") == 0) {
-											vala_method_set_printf_format (self, TRUE);
-										} else {
-											if (g_utf8_collate (vala_attribute_get_name (a), "Import") == 0) {
-												vala_symbol_set_is_imported (VALA_SYMBOL (self), TRUE);
-											}
+										if (g_utf8_collate (vala_attribute_get_name (a), "Import") == 0) {
+											vala_symbol_set_is_imported (VALA_SYMBOL (self), TRUE);
 										}
 									}
 								}
@@ -406,8 +385,7 @@ void vala_method_process_attributes (ValaMethod* self)
  * @param m a method
  * @return  true if the specified method is compatible to this method
  */
-gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2)
-{
+gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
 	GeeCollection* _tmp1;
 	GeeIterator* _tmp2;
 	GeeIterator* method_params_it;
@@ -494,8 +472,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2)
  *
  * @param error_domain an error domain
  */
-void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_domain)
-{
+void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_domain) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (error_domain));
 	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), error_domain);
@@ -507,22 +484,19 @@ void vala_method_add_error_domain (ValaMethod* self, ValaTypeReference* error_do
  *
  * @return list of error domains
  */
-GeeCollection* vala_method_get_error_domains (ValaMethod* self)
-{
+GeeCollection* vala_method_get_error_domains (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->error_domains)));
 }
 
 
-ValaTypeReference* vala_method_get_return_type (ValaMethod* self)
-{
+ValaTypeReference* vala_method_get_return_type (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_return_type;
 }
 
 
-void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value)
-{
+void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value) {
 	ValaTypeReference* _tmp2;
 	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
@@ -532,15 +506,13 @@ void vala_method_set_return_type (ValaMethod* self, ValaTypeReference* value)
 }
 
 
-ValaBlock* vala_method_get_body (ValaMethod* self)
-{
+ValaBlock* vala_method_get_body (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_method_set_body (ValaMethod* self, ValaBlock* value)
-{
+void vala_method_set_body (ValaMethod* self, ValaBlock* value) {
 	ValaBlock* _tmp2;
 	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
@@ -550,36 +522,32 @@ void vala_method_set_body (ValaMethod* self, ValaBlock* value)
 }
 
 
-gboolean vala_method_get_instance (ValaMethod* self)
-{
+gboolean vala_method_get_instance (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_instance;
 }
 
 
-void vala_method_set_instance (ValaMethod* self, gboolean value)
-{
+void vala_method_set_instance (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_instance = value;
 }
 
 
-char* vala_method_get_vfunc_name (ValaMethod* self)
-{
+char* vala_method_get_vfunc_name (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (self->priv->_vfunc_name == NULL) {
 		char* _tmp1;
 		const char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		self->priv->_vfunc_name = (_tmp1 = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL)), _tmp1);
+		self->priv->_vfunc_name = (_tmp1 = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL)), _tmp1);
 	}
 	return self->priv->_vfunc_name;
 }
 
 
-void vala_method_set_vfunc_name (ValaMethod* self, const char* value)
-{
+void vala_method_set_vfunc_name (ValaMethod* self, const char* value) {
 	char* _tmp3;
 	g_return_if_fail (VALA_IS_METHOD (self));
 	_tmp3 = NULL;
@@ -587,8 +555,7 @@ void vala_method_set_vfunc_name (ValaMethod* self, const char* value)
 }
 
 
-char* vala_method_get_sentinel (ValaMethod* self)
-{
+char* vala_method_get_sentinel (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (self->priv->_sentinel == NULL) {
 		return VALA_METHOD_DEFAULT_SENTINEL;
@@ -597,8 +564,7 @@ char* vala_method_get_sentinel (ValaMethod* self)
 }
 
 
-void vala_method_set_sentinel (ValaMethod* self, const char* value)
-{
+void vala_method_set_sentinel (ValaMethod* self, const char* value) {
 	char* _tmp2;
 	g_return_if_fail (VALA_IS_METHOD (self));
 	_tmp2 = NULL;
@@ -606,113 +572,85 @@ void vala_method_set_sentinel (ValaMethod* self, const char* value)
 }
 
 
-gboolean vala_method_get_is_abstract (ValaMethod* self)
-{
+gboolean vala_method_get_is_abstract (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_is_abstract;
 }
 
 
-void vala_method_set_is_abstract (ValaMethod* self, gboolean value)
-{
+void vala_method_set_is_abstract (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_is_abstract = value;
 }
 
 
-gboolean vala_method_get_is_virtual (ValaMethod* self)
-{
+gboolean vala_method_get_is_virtual (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_is_virtual;
 }
 
 
-void vala_method_set_is_virtual (ValaMethod* self, gboolean value)
-{
+void vala_method_set_is_virtual (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_is_virtual = value;
 }
 
 
-gboolean vala_method_get_overrides (ValaMethod* self)
-{
+gboolean vala_method_get_overrides (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_overrides;
 }
 
 
-void vala_method_set_overrides (ValaMethod* self, gboolean value)
-{
+void vala_method_set_overrides (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_overrides = value;
 }
 
 
-gboolean vala_method_get_returns_modified_pointer (ValaMethod* self)
-{
+gboolean vala_method_get_returns_modified_pointer (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_returns_modified_pointer;
 }
 
 
-void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value)
-{
+void vala_method_set_returns_modified_pointer (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_returns_modified_pointer = value;
 }
 
 
-gboolean vala_method_get_instance_last (ValaMethod* self)
-{
+gboolean vala_method_get_instance_last (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_instance_last;
 }
 
 
-void vala_method_set_instance_last (ValaMethod* self, gboolean value)
-{
+void vala_method_set_instance_last (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_instance_last = value;
 }
 
 
-gboolean vala_method_get_instance_by_reference (ValaMethod* self)
-{
-	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
-	return self->priv->_instance_by_reference;
-}
-
-
-void vala_method_set_instance_by_reference (ValaMethod* self, gboolean value)
-{
-	g_return_if_fail (VALA_IS_METHOD (self));
-	self->priv->_instance_by_reference = value;
-}
-
-
-ValaMethod* vala_method_get_base_method (ValaMethod* self)
-{
+ValaMethod* vala_method_get_base_method (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_base_method;
 }
 
 
-void vala_method_set_base_method (ValaMethod* self, ValaMethod* value)
-{
+void vala_method_set_base_method (ValaMethod* self, ValaMethod* value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_base_method = value;
 }
 
 
-ValaMethod* vala_method_get_base_interface_method (ValaMethod* self)
-{
+ValaMethod* vala_method_get_base_interface_method (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_base_interface_method;
 }
 
 
-void vala_method_set_base_interface_method (ValaMethod* self, ValaMethod* value)
-{
+void vala_method_set_base_interface_method (ValaMethod* self, ValaMethod* value) {
 	ValaMethod* _tmp2;
 	ValaMethod* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
@@ -722,15 +660,13 @@ void vala_method_set_base_interface_method (ValaMethod* self, ValaMethod* value)
 }
 
 
-ValaFormalParameter* vala_method_get_this_parameter (ValaMethod* self)
-{
+ValaFormalParameter* vala_method_get_this_parameter (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_this_parameter;
 }
 
 
-void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* value)
-{
+void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* value) {
 	ValaFormalParameter* _tmp2;
 	ValaFormalParameter* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
@@ -740,15 +676,13 @@ void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* valu
 }
 
 
-gboolean vala_method_get_no_array_length (ValaMethod* self)
-{
+gboolean vala_method_get_no_array_length (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_no_array_length;
 }
 
 
-void vala_method_set_no_array_length (ValaMethod* self, gboolean value)
-{
+void vala_method_set_no_array_length (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_no_array_length = value;
 	{
@@ -769,22 +703,19 @@ void vala_method_set_no_array_length (ValaMethod* self, gboolean value)
 }
 
 
-gboolean vala_method_get_printf_format (ValaMethod* self)
-{
+gboolean vala_method_get_printf_format (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
 	return self->priv->_printf_format;
 }
 
 
-void vala_method_set_printf_format (ValaMethod* self, gboolean value)
-{
+void vala_method_set_printf_format (ValaMethod* self, gboolean value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
 	self->priv->_printf_format = value;
 }
 
 
-static void vala_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaMethod * self;
 	self = VALA_METHOD (object);
 	switch (property_id) {
@@ -818,9 +749,6 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_INSTANCE_LAST:
 		g_value_set_boolean (value, vala_method_get_instance_last (self));
 		break;
-		case VALA_METHOD_INSTANCE_BY_REFERENCE:
-		g_value_set_boolean (value, vala_method_get_instance_by_reference (self));
-		break;
 		case VALA_METHOD_BASE_METHOD:
 		g_value_set_object (value, vala_method_get_base_method (self));
 		break;
@@ -843,8 +771,7 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 }
 
 
-static void vala_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaMethod * self;
 	self = VALA_METHOD (object);
 	switch (property_id) {
@@ -878,9 +805,6 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_INSTANCE_LAST:
 		vala_method_set_instance_last (self, g_value_get_boolean (value));
 		break;
-		case VALA_METHOD_INSTANCE_BY_REFERENCE:
-		vala_method_set_instance_by_reference (self, g_value_get_boolean (value));
-		break;
 		case VALA_METHOD_BASE_METHOD:
 		vala_method_set_base_method (self, g_value_get_object (value));
 		break;
@@ -903,8 +827,7 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 }
 
 
-static void vala_method_class_init (ValaMethodClass * klass)
-{
+static void vala_method_class_init (ValaMethodClass * klass) {
 	vala_method_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaMethodPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_method_get_property;
@@ -913,27 +836,25 @@ static void vala_method_class_init (ValaMethodClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_method_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_method_real_get_default_cname;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_VFUNC_NAME, g_param_spec_string ("vfunc-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_SENTINEL, g_param_spec_string ("sentinel", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_OVERRIDES, g_param_spec_boolean ("overrides", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURNS_MODIFIED_POINTER, g_param_spec_boolean ("returns-modified-pointer", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE_LAST, g_param_spec_boolean ("instance-last", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE_BY_REFERENCE, g_param_spec_boolean ("instance-by-reference", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_METHOD, g_param_spec_object ("base-method", "foo", "bar", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_INTERFACE_METHOD, g_param_spec_object ("base-interface-method", "foo", "bar", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_THIS_PARAMETER, g_param_spec_object ("this-parameter", "foo", "bar", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_PRINTF_FORMAT, g_param_spec_boolean ("printf-format", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_VFUNC_NAME, g_param_spec_string ("vfunc-name", "vfunc-name", "vfunc-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_SENTINEL, g_param_spec_string ("sentinel", "sentinel", "sentinel", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURNS_MODIFIED_POINTER, g_param_spec_boolean ("returns-modified-pointer", "returns-modified-pointer", "returns-modified-pointer", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE_LAST, g_param_spec_boolean ("instance-last", "instance-last", "instance-last", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_METHOD, g_param_spec_object ("base-method", "base-method", "base-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_INTERFACE_METHOD, g_param_spec_object ("base-interface-method", "base-interface-method", "base-interface-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_PRINTF_FORMAT, g_param_spec_boolean ("printf-format", "printf-format", "printf-format", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_method_vala_invokable_interface_init (ValaInvokableIface * iface)
-{
+static void vala_method_vala_invokable_interface_init (ValaInvokableIface * iface) {
 	vala_method_vala_invokable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->get_parameters = vala_method_real_get_parameters;
 	iface->get_return_type = vala_method_real_get_return_type;
@@ -941,8 +862,7 @@ static void vala_method_vala_invokable_interface_init (ValaInvokableIface * ifac
 }
 
 
-static void vala_method_init (ValaMethod * self)
-{
+static void vala_method_init (ValaMethod * self) {
 	self->priv = VALA_METHOD_GET_PRIVATE (self);
 	self->priv->_instance = TRUE;
 	self->priv->parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
@@ -950,11 +870,8 @@ static void vala_method_init (ValaMethod * self)
 }
 
 
-static void vala_method_dispose (GObject * obj)
-{
+static void vala_method_dispose (GObject * obj) {
 	ValaMethod * self;
-	ValaMethodClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_METHOD (obj);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
@@ -965,14 +882,11 @@ static void vala_method_dispose (GObject * obj)
 	(self->priv->_vfunc_name = (g_free (self->priv->_vfunc_name), NULL));
 	(self->priv->_sentinel = (g_free (self->priv->_sentinel), NULL));
 	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
-	klass = VALA_METHOD_CLASS (g_type_class_peek (VALA_TYPE_METHOD));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_method_parent_class)->dispose (obj);
 }
 
 
-GType vala_method_get_type (void)
-{
+GType vala_method_get_type (void) {
 	static GType vala_method_type_id = 0;
 	if (G_UNLIKELY (vala_method_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMethod), 0, (GInstanceInitFunc) vala_method_init };
@@ -984,8 +898,7 @@ GType vala_method_get_type (void)
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
-{
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
 		if (array_length >= 0)
