@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valapointerindirection.h"
-#include <vala/valasourcereference.h>
 #include <vala/valapointerindirection.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaPointerIndirectionPrivate {
@@ -45,8 +44,7 @@ static void vala_pointer_indirection_dispose (GObject * obj);
  * @param inner pointer to be dereferenced
  * @return      newly created pointer indirection
  */
-ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, ValaSourceReference* source_reference)
-{
+ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaPointerIndirection * self;
@@ -66,20 +64,18 @@ ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, Val
 }
 
 
-static void vala_pointer_indirection_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_pointer_indirection_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPointerIndirection * self;
-	self = ((ValaPointerIndirection*) base);
+	self = VALA_POINTER_INDIRECTION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_pointer_indirection_get_inner (self)), visitor);
 	vala_code_visitor_visit_pointer_indirection (visitor, self);
 }
 
 
-static void vala_pointer_indirection_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_pointer_indirection_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaPointerIndirection * self;
-	self = ((ValaPointerIndirection*) base);
+	self = VALA_POINTER_INDIRECTION (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_pointer_indirection_get_inner (self)) == old_node) {
@@ -88,49 +84,50 @@ static void vala_pointer_indirection_real_replace (ValaCodeNode* base, ValaCodeN
 }
 
 
-ValaExpression* vala_pointer_indirection_get_inner (ValaPointerIndirection* self)
-{
+ValaExpression* vala_pointer_indirection_get_inner (ValaPointerIndirection* self) {
 	g_return_val_if_fail (VALA_IS_POINTER_INDIRECTION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpression* value)
-{
-	ValaExpression* __temp1;
+void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpression* value) {
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_POINTER_INDIRECTION (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
-static void vala_pointer_indirection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_pointer_indirection_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaPointerIndirection * self;
 	self = VALA_POINTER_INDIRECTION (object);
 	switch (property_id) {
 		case VALA_POINTER_INDIRECTION_INNER:
 		g_value_set_object (value, vala_pointer_indirection_get_inner (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_pointer_indirection_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_pointer_indirection_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaPointerIndirection * self;
 	self = VALA_POINTER_INDIRECTION (object);
 	switch (property_id) {
 		case VALA_POINTER_INDIRECTION_INNER:
 		vala_pointer_indirection_set_inner (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_pointer_indirection_class_init (ValaPointerIndirectionClass * klass)
-{
+static void vala_pointer_indirection_class_init (ValaPointerIndirectionClass * klass) {
 	vala_pointer_indirection_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaPointerIndirectionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_pointer_indirection_get_property;
@@ -138,31 +135,24 @@ static void vala_pointer_indirection_class_init (ValaPointerIndirectionClass * k
 	G_OBJECT_CLASS (klass)->dispose = vala_pointer_indirection_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_pointer_indirection_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_pointer_indirection_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POINTER_INDIRECTION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POINTER_INDIRECTION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_pointer_indirection_init (ValaPointerIndirection * self)
-{
+static void vala_pointer_indirection_init (ValaPointerIndirection * self) {
 	self->priv = VALA_POINTER_INDIRECTION_GET_PRIVATE (self);
 }
 
 
-static void vala_pointer_indirection_dispose (GObject * obj)
-{
+static void vala_pointer_indirection_dispose (GObject * obj) {
 	ValaPointerIndirection * self;
-	ValaPointerIndirectionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_POINTER_INDIRECTION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_POINTER_INDIRECTION_CLASS (g_type_class_peek (VALA_TYPE_POINTER_INDIRECTION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_pointer_indirection_parent_class)->dispose (obj);
 }
 
 
-GType vala_pointer_indirection_get_type (void)
-{
+GType vala_pointer_indirection_get_type (void) {
 	static GType vala_pointer_indirection_type_id = 0;
 	if (G_UNLIKELY (vala_pointer_indirection_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaPointerIndirectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_pointer_indirection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPointerIndirection), 0, (GInstanceInitFunc) vala_pointer_indirection_init };
