@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAREALLITERAL_H__
-#define __VALAREALLITERAL_H__
+#ifndef __VALA_VALAREALLITERAL_H__
+#define __VALA_VALAREALLITERAL_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -57,7 +57,7 @@ ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* sour
 char* vala_real_literal_get_type_name (ValaRealLiteral* self);
 char* vala_real_literal_get_value (ValaRealLiteral* self);
 void vala_real_literal_set_value (ValaRealLiteral* self, const char* value);
-GType vala_real_literal_get_type ();
+GType vala_real_literal_get_type (void);
 
 G_END_DECLS
 
