@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valasourcefilecycle.h"
+#include <vala/valasourcefilecycle.h>
 #include <gee/arraylist.h>
 
 enum  {
@@ -30,34 +30,36 @@ static gpointer vala_source_file_cycle_parent_class = NULL;
 static void vala_source_file_cycle_dispose (GObject * obj);
 
 
-static void vala_source_file_cycle_class_init (ValaSourceFileCycleClass * klass)
-{
+/**
+ * Represents a dependency cycle of source files.
+ */
+ValaSourceFileCycle* vala_source_file_cycle_new (void) {
+	ValaSourceFileCycle * self;
+	self = g_object_newv (VALA_TYPE_SOURCE_FILE_CYCLE, 0, NULL);
+	return self;
+}
+
+
+static void vala_source_file_cycle_class_init (ValaSourceFileCycleClass * klass) {
 	vala_source_file_cycle_parent_class = g_type_class_peek_parent (klass);
 	G_OBJECT_CLASS (klass)->dispose = vala_source_file_cycle_dispose;
 }
 
 
-static void vala_source_file_cycle_init (ValaSourceFileCycle * self)
-{
+static void vala_source_file_cycle_init (ValaSourceFileCycle * self) {
 	self->files = GEE_LIST (gee_array_list_new (NULL, NULL, g_direct_equal));
 }
 
 
-static void vala_source_file_cycle_dispose (GObject * obj)
-{
+static void vala_source_file_cycle_dispose (GObject * obj) {
 	ValaSourceFileCycle * self;
-	ValaSourceFileCycleClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SOURCE_FILE_CYCLE (obj);
 	(self->files == NULL ? NULL : (self->files = (g_object_unref (self->files), NULL)));
-	klass = VALA_SOURCE_FILE_CYCLE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_FILE_CYCLE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_source_file_cycle_parent_class)->dispose (obj);
 }
 
 
-GType vala_source_file_cycle_get_type (void)
-{
+GType vala_source_file_cycle_get_type (void) {
 	static GType vala_source_file_cycle_type_id = 0;
 	if (G_UNLIKELY (vala_source_file_cycle_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceFileCycleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_file_cycle_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceFileCycle), 0, (GInstanceInitFunc) vala_source_file_cycle_init };
