@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaswitchlabel.h"
+#include <vala/valaswitchlabel.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaswitchlabel.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaSwitchLabelPrivate {
@@ -46,8 +45,7 @@ static void vala_switch_label_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created switch case label
  */
-ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReference* source)
-{
+ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReference* source) {
 	ValaSwitchLabel * self;
 	g_return_val_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
@@ -64,8 +62,7 @@ ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReferenc
  * @param source reference to source code
  * @return       newly created switch default label
  */
-ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source)
-{
+ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source) {
 	ValaSwitchLabel * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_SWITCH_LABEL, 0, NULL);
@@ -74,10 +71,9 @@ ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source
 }
 
 
-static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchLabel * self;
-	self = ((ValaSwitchLabel*) base);
+	self = VALA_SWITCH_LABEL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_switch_label_get_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_switch_label_get_expression (self)), visitor);
@@ -87,81 +83,75 @@ static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self)
-{
+ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_LABEL (self), NULL);
 	return self->priv->_expression;
 }
 
 
-void vala_switch_label_set_expression (ValaSwitchLabel* self, ValaExpression* value)
-{
-	ValaExpression* __temp2;
-	ValaExpression* __temp1;
+void vala_switch_label_set_expression (ValaSwitchLabel* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_SWITCH_LABEL (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
-static void vala_switch_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_switch_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSwitchLabel * self;
 	self = VALA_SWITCH_LABEL (object);
 	switch (property_id) {
 		case VALA_SWITCH_LABEL_EXPRESSION:
 		g_value_set_object (value, vala_switch_label_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_switch_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_switch_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaSwitchLabel * self;
 	self = VALA_SWITCH_LABEL (object);
 	switch (property_id) {
 		case VALA_SWITCH_LABEL_EXPRESSION:
 		vala_switch_label_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_switch_label_class_init (ValaSwitchLabelClass * klass)
-{
+static void vala_switch_label_class_init (ValaSwitchLabelClass * klass) {
 	vala_switch_label_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaSwitchLabelPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_switch_label_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_switch_label_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_switch_label_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_switch_label_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SWITCH_LABEL_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SWITCH_LABEL_EXPRESSION, g_param_spec_object ("expression", "expression", "expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_switch_label_init (ValaSwitchLabel * self)
-{
+static void vala_switch_label_init (ValaSwitchLabel * self) {
 	self->priv = VALA_SWITCH_LABEL_GET_PRIVATE (self);
 }
 
 
-static void vala_switch_label_dispose (GObject * obj)
-{
+static void vala_switch_label_dispose (GObject * obj) {
 	ValaSwitchLabel * self;
-	ValaSwitchLabelClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_SWITCH_LABEL (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	klass = VALA_SWITCH_LABEL_CLASS (g_type_class_peek (VALA_TYPE_SWITCH_LABEL));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_switch_label_parent_class)->dispose (obj);
 }
 
 
-GType vala_switch_label_get_type (void)
-{
+GType vala_switch_label_get_type (void) {
 	static GType vala_switch_label_type_id = 0;
 	if (G_UNLIKELY (vala_switch_label_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchLabel), 0, (GInstanceInitFunc) vala_switch_label_init };
