@@ -9,7 +9,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,14 +25,13 @@
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
 
-#include "valatypereference.h"
+#include <vala/valatypereference.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
 #include <gee/readonlylist.h>
 #include <vala/valadatatype.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valasourcereference.h>
-#include <vala/valatypereference.h>
 #include <vala/valaexpression.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valareport.h>
@@ -80,8 +79,7 @@ static gpointer vala_type_reference_parent_class = NULL;
 static void vala_type_reference_dispose (GObject * obj);
 
 
-ValaTypeReference* vala_type_reference_new (void)
-{
+ValaTypeReference* vala_type_reference_new (void) {
 	ValaTypeReference * self;
 	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, 0, NULL);
 	return self;
@@ -96,8 +94,7 @@ ValaTypeReference* vala_type_reference_new (void)
  * @param source    reference to source code
  * @return          newly created type reference
  */
-ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char* type, ValaSourceReference* source)
-{
+ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char* type, ValaSourceReference* source) {
 	ValaTypeReference * self;
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
@@ -116,8 +113,7 @@ ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char
  * @param source reference to source code
  * @return       newly created type reference
  */
-ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr)
-{
+ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr) {
 	char* ns;
 	char* type_name;
 	gpointer _tmp5;
@@ -139,13 +135,13 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 				_tmp1 = NULL;
 				simple = (_tmp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 				_tmp2 = NULL;
-				type_ref = (_tmp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp2);
+				type_ref = (_tmp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp2);
 				(simple == NULL ? NULL : (simple = (g_object_unref (simple), NULL)));
 			}
 		} else {
 			ValaTypeReference* _tmp3;
 			_tmp3 = NULL;
-			type_ref = (_tmp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp3);
+			type_ref = (_tmp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), _tmp3);
 		}
 		if (type_ref != NULL) {
 			GeeCollection* type_args;
@@ -173,8 +169,8 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 		(type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL)));
 		(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	}
-	vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) expr)), "Type reference must be simple name or member access expression");
-	return VALA_TYPE_REFERENCE ((_tmp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp5));
+	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (expr)), "Type reference must be simple name or member access expression");
+	return (_tmp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), _tmp5);
 	(ns = (g_free (ns), NULL));
 	(type_name = (g_free (type_name), NULL));
 }
@@ -185,8 +181,7 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
  *
  * @param arg a type reference
  */
-void vala_type_reference_add_type_argument (ValaTypeReference* self, ValaTypeReference* arg)
-{
+void vala_type_reference_add_type_argument (ValaTypeReference* self, ValaTypeReference* arg) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
@@ -198,8 +193,7 @@ void vala_type_reference_add_type_argument (ValaTypeReference* self, ValaTypeRef
  *
  * @return type argument list
  */
-GeeList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
-{
+GeeList* vala_type_reference_get_type_arguments (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, GEE_LIST (self->priv->type_argument_list)));
 }
@@ -208,19 +202,17 @@ GeeList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
 /**
  * Removes all generic type arguments.
  */
-void vala_type_reference_remove_all_type_arguments (ValaTypeReference* self)
-{
+void vala_type_reference_remove_all_type_arguments (ValaTypeReference* self) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	gee_collection_clear (GEE_COLLECTION (self->priv->type_argument_list));
 }
 
 
-static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeReference * self;
-	self = ((ValaTypeReference*) base);
+	self = VALA_TYPE_REFERENCE (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	if (gee_collection_get_size (((GeeCollection*) (GEE_LIST (self->priv->type_argument_list)))) > 0) {
+	if (gee_collection_get_size (GEE_COLLECTION ((GEE_LIST (self->priv->type_argument_list)))) > 0) {
 		{
 			GeeArrayList* type_arg_collection;
 			GeeIterator* type_arg_it;
@@ -246,8 +238,7 @@ static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor
  *
  * @return the type string to be used in C code
  */
-char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type, gboolean const_type)
-{
+char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type, gboolean const_type) {
 	char* ptr;
 	char* arr;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
@@ -291,7 +282,7 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
 		} else {
 			gpointer _tmp9;
 			/* raise error */
-			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), "unresolved type reference");
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
 			return (_tmp9 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), _tmp9);
 		}
 	}
@@ -306,8 +297,7 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
  *
  * @return the type string to be used in C code const declarations
  */
-char* vala_type_reference_get_const_cname (ValaTypeReference* self)
-{
+char* vala_type_reference_get_const_cname (ValaTypeReference* self) {
 	char* ptr;
 	ValaDataType* t;
 	char* _tmp6;
@@ -354,8 +344,7 @@ char* vala_type_reference_get_const_cname (ValaTypeReference* self)
  *
  * @return display name
  */
-char* vala_type_reference_to_string (ValaTypeReference* self)
-{
+char* vala_type_reference_to_string (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	if (vala_type_reference_get_data_type (self) != NULL) {
 		return vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (self)));
@@ -363,7 +352,7 @@ char* vala_type_reference_to_string (ValaTypeReference* self)
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
 			const char* _tmp1;
 			_tmp1 = NULL;
-			return (_tmp1 = vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (self))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+			return (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (vala_type_reference_get_type_parameter (self))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 		} else {
 			return g_strdup ("null");
 		}
@@ -376,12 +365,11 @@ char* vala_type_reference_to_string (ValaTypeReference* self)
  *
  * @return copy of this type reference
  */
-ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
-{
+ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self) {
 	ValaTypeReference* result;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	result = vala_type_reference_new ();
-	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (((ValaCodeNode*) self)));
+	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 	vala_type_reference_set_transfers_ownership (result, vala_type_reference_get_transfers_ownership (self));
 	vala_type_reference_set_takes_ownership (result, vala_type_reference_get_takes_ownership (self));
 	vala_type_reference_set_is_out (result, vala_type_reference_get_is_out (self));
@@ -426,8 +414,7 @@ ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
  * @return      true if this type reference is equal to type2, false
  *              otherwise
  */
-gboolean vala_type_reference_equals (ValaTypeReference* self, ValaTypeReference* type2)
-{
+gboolean vala_type_reference_equals (ValaTypeReference* self, ValaTypeReference* type2) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type2), FALSE);
 	if (vala_type_reference_get_transfers_ownership (type2) != vala_type_reference_get_transfers_ownership (self)) {
@@ -470,8 +457,7 @@ gboolean vala_type_reference_equals (ValaTypeReference* self, ValaTypeReference*
  * @param type2 a type reference
  * @return      true if this type reference is stricter or equal
  */
-gboolean vala_type_reference_stricter (ValaTypeReference* self, ValaTypeReference* type2)
-{
+gboolean vala_type_reference_stricter (ValaTypeReference* self, ValaTypeReference* type2) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type2), FALSE);
 	if (vala_type_reference_get_transfers_ownership (type2) != vala_type_reference_get_transfers_ownership (self)) {
@@ -504,99 +490,85 @@ gboolean vala_type_reference_stricter (ValaTypeReference* self, ValaTypeReferenc
 }
 
 
-gboolean vala_type_reference_get_transfers_ownership (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_transfers_ownership (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_transfers_ownership;
 }
 
 
-void vala_type_reference_set_transfers_ownership (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_transfers_ownership (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_transfers_ownership = value;
 }
 
 
-gboolean vala_type_reference_get_takes_ownership (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_takes_ownership (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_takes_ownership;
 }
 
 
-void vala_type_reference_set_takes_ownership (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_takes_ownership (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_takes_ownership = value;
 }
 
 
-gboolean vala_type_reference_get_is_out (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_is_out (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_is_out;
 }
 
 
-void vala_type_reference_set_is_out (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_is_out (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_is_out = value;
 }
 
 
-gboolean vala_type_reference_get_non_null (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_non_null (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_non_null;
 }
 
 
-void vala_type_reference_set_non_null (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_non_null (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_non_null = value;
 }
 
 
-gboolean vala_type_reference_get_is_null (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_is_null (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_is_null;
 }
 
 
-void vala_type_reference_set_is_null (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_is_null (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_is_null = value;
 }
 
 
-ValaDataType* vala_type_reference_get_data_type (ValaTypeReference* self)
-{
+ValaDataType* vala_type_reference_get_data_type (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_type_reference_set_data_type (ValaTypeReference* self, ValaDataType* value)
-{
+void vala_type_reference_set_data_type (ValaTypeReference* self, ValaDataType* value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_data_type = value;
 }
 
 
-ValaTypeParameter* vala_type_reference_get_type_parameter (ValaTypeReference* self)
-{
+ValaTypeParameter* vala_type_reference_get_type_parameter (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	return self->priv->_type_parameter;
 }
 
 
-void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypeParameter* value)
-{
+void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypeParameter* value) {
 	ValaTypeParameter* _tmp2;
 	ValaTypeParameter* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
@@ -606,29 +578,25 @@ void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypePa
 }
 
 
-gboolean vala_type_reference_get_floating_reference (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_floating_reference (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_floating_reference;
 }
 
 
-void vala_type_reference_set_floating_reference (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_floating_reference (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_floating_reference = value;
 }
 
 
-char* vala_type_reference_get_namespace_name (ValaTypeReference* self)
-{
+char* vala_type_reference_get_namespace_name (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	return self->priv->_namespace_name;
 }
 
 
-void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char* value)
-{
+void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
@@ -638,15 +606,13 @@ void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char
 }
 
 
-char* vala_type_reference_get_type_name (ValaTypeReference* self)
-{
+char* vala_type_reference_get_type_name (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	return self->priv->_type_name;
 }
 
 
-void vala_type_reference_set_type_name (ValaTypeReference* self, const char* value)
-{
+void vala_type_reference_set_type_name (ValaTypeReference* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
@@ -656,64 +622,55 @@ void vala_type_reference_set_type_name (ValaTypeReference* self, const char* val
 }
 
 
-gint vala_type_reference_get_array_rank (ValaTypeReference* self)
-{
+gint vala_type_reference_get_array_rank (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), 0);
 	return self->priv->_array_rank;
 }
 
 
-void vala_type_reference_set_array_rank (ValaTypeReference* self, gint value)
-{
+void vala_type_reference_set_array_rank (ValaTypeReference* self, gint value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_array_rank = value;
 }
 
 
-gint vala_type_reference_get_pointer_level (ValaTypeReference* self)
-{
+gint vala_type_reference_get_pointer_level (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), 0);
 	return self->priv->_pointer_level;
 }
 
 
-void vala_type_reference_set_pointer_level (ValaTypeReference* self, gint value)
-{
+void vala_type_reference_set_pointer_level (ValaTypeReference* self, gint value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_pointer_level = value;
 }
 
 
-gboolean vala_type_reference_get_is_ref (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_is_ref (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_is_ref;
 }
 
 
-void vala_type_reference_set_is_ref (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_is_ref (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_is_ref = value;
 }
 
 
-gboolean vala_type_reference_get_is_weak (ValaTypeReference* self)
-{
+gboolean vala_type_reference_get_is_weak (ValaTypeReference* self) {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), FALSE);
 	return self->priv->_is_weak;
 }
 
 
-void vala_type_reference_set_is_weak (ValaTypeReference* self, gboolean value)
-{
+void vala_type_reference_set_is_weak (ValaTypeReference* self, gboolean value) {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	self->priv->_is_weak = value;
 }
 
 
-static void vala_type_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_type_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaTypeReference * self;
 	self = VALA_TYPE_REFERENCE (object);
 	switch (property_id) {
@@ -766,8 +723,7 @@ static void vala_type_reference_get_property (GObject * object, guint property_i
 }
 
 
-static void vala_type_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_type_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaTypeReference * self;
 	self = VALA_TYPE_REFERENCE (object);
 	switch (property_id) {
@@ -820,56 +776,48 @@ static void vala_type_reference_set_property (GObject * object, guint property_i
 }
 
 
-static void vala_type_reference_class_init (ValaTypeReferenceClass * klass)
-{
+static void vala_type_reference_class_init (ValaTypeReferenceClass * klass) {
 	vala_type_reference_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaTypeReferencePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_type_reference_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_type_reference_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_type_reference_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_type_reference_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_OUT, g_param_spec_boolean ("is-out", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_NON_NULL, g_param_spec_boolean ("non-null", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_NULL, g_param_spec_boolean ("is-null", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_DATA_TYPE, g_param_spec_object ("data-type", "foo", "bar", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TYPE_PARAMETER, g_param_spec_object ("type-parameter", "foo", "bar", VALA_TYPE_TYPE_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_FLOATING_REFERENCE, g_param_spec_boolean ("floating-reference", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_NAMESPACE_NAME, g_param_spec_string ("namespace-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TYPE_NAME, g_param_spec_string ("type-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_ARRAY_RANK, g_param_spec_int ("array-rank", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_POINTER_LEVEL, g_param_spec_int ("pointer-level", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_REF, g_param_spec_boolean ("is-ref", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_WEAK, g_param_spec_boolean ("is-weak", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "transfers-ownership", "transfers-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "takes-ownership", "takes-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_OUT, g_param_spec_boolean ("is-out", "is-out", "is-out", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_NON_NULL, g_param_spec_boolean ("non-null", "non-null", "non-null", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_NULL, g_param_spec_boolean ("is-null", "is-null", "is-null", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_DATA_TYPE, g_param_spec_object ("data-type", "data-type", "data-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TYPE_PARAMETER, g_param_spec_object ("type-parameter", "type-parameter", "type-parameter", VALA_TYPE_TYPE_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_FLOATING_REFERENCE, g_param_spec_boolean ("floating-reference", "floating-reference", "floating-reference", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_NAMESPACE_NAME, g_param_spec_string ("namespace-name", "namespace-name", "namespace-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_ARRAY_RANK, g_param_spec_int ("array-rank", "array-rank", "array-rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_POINTER_LEVEL, g_param_spec_int ("pointer-level", "pointer-level", "pointer-level", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_REF, g_param_spec_boolean ("is-ref", "is-ref", "is-ref", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPE_REFERENCE_IS_WEAK, g_param_spec_boolean ("is-weak", "is-weak", "is-weak", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_type_reference_init (ValaTypeReference * self)
-{
+static void vala_type_reference_init (ValaTypeReference * self) {
 	self->priv = VALA_TYPE_REFERENCE_GET_PRIVATE (self);
 	self->priv->type_argument_list = gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal);
 }
 
 
-static void vala_type_reference_dispose (GObject * obj)
-{
+static void vala_type_reference_dispose (GObject * obj) {
 	ValaTypeReference * self;
-	ValaTypeReferenceClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_TYPE_REFERENCE (obj);
 	(self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL)));
 	(self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL));
 	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
 	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
-	klass = VALA_TYPE_REFERENCE_CLASS (g_type_class_peek (VALA_TYPE_TYPE_REFERENCE));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_type_reference_parent_class)->dispose (obj);
 }
 
 
-GType vala_type_reference_get_type (void)
-{
+GType vala_type_reference_get_type (void) {
 	static GType vala_type_reference_type_id = 0;
 	if (G_UNLIKELY (vala_type_reference_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_type_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeReference), 0, (GInstanceInitFunc) vala_type_reference_init };
